# Items Synchronizer

## Description

TODO Add a diagram to explain it.

Synchronize items from two different sources.

This library aims to offer an abstract and versatile way to _create_, _update_
and/or _delete_ items to keep two "sources" in bi-directional sync.

These "items" may range from Calendar entries, TODO task lists, or whatever else
you want as long as the user registers the appropriate functions/methods to
convert from one said item to another.

## Installation

Add it as a dependency to either your `requirements.txt` or to `pyproject.toml`

TODO - Add example

## Example Usage

Projects using this:

* [Taskwarrior <-> Google Calendar Bidirectonal Synchronisation](https://github.com/bergercookie/taskw_gcal_sync/blob/master/taskw_gcal_sync/TWGCalAggregator.py)

<!-- ## TODO Extra Configuration -->
